using System;
using System.Linq;
using CoreGraphics;
using CoreFoundation;
using ObjCRuntime;
using UIKit;
using Foundation;
using System.Collections.Generic;
using Steema.TeeChart;

namespace TeeChartTest
{
	[Foundation.Register("TestView")]
	public class TestView : UIViewController
    {
		private static nfloat SPACING = 6.0f;

		private TChart Chart;

        public sealed override void ViewDidLoad()
        {
	        base.ViewDidLoad();

			nfloat w = View.Bounds.Width;
			nfloat h = this.View.Bounds.Height;
			nfloat y = SPACING * 3;

			// Chart
			this.Chart = new TChart()
			{
				Frame = new CGRect(8, y, w - 16, h - (y * 2f) - (SPACING * 2f))
			};
			
			this.CreateChartUI();
			this.View.AddSubview(this.Chart);

			this.UpdateChart();
        }

		private void CreateChartUI()
		{
			CGColor textColor = UIColor.Black.CGColor;

			this.Chart.Aspect.View3D = false;
			//this.Chart.Aspect.Chart3DPercent = 0;
			this.Chart.Header.Text = String.Empty;
			this.Chart.Aspect.ZoomScrollStyle = Steema.TeeChart.Drawing.Aspect.ZoomScrollStyles.Manual;
			this.Chart.Zoom.Active = false;
			this.Chart.Zoom.Allow = false;
			this.Chart.Panning.Allow = ScrollModes.None;
			this.Chart.Legend.Visible = false;
			this.Chart.Header.Text = "Test";
			this.Chart.GetAxisLabel += Chart_GetAxisLabel;

			// Walls
			this.Chart.Walls.Back.Pen.Visible = false;
			this.Chart.Walls.Back.Gradient.Visible = false;
			this.Chart.Walls.Back.Color = UIColor.Gray.CGColor;

			// Left axis
			this.Chart.Axes.Left.AxisPen.Visible = false;
			//this.Chart.Axes.Left.Grid.Visible = false;
			this.Chart.Axes.Left.Ticks.Visible = false;
			this.Chart.Axes.Left.MinorTicks.Visible = false;
			this.Chart.Axes.Left.MinorGrid.Visible = false;
			this.Chart.Axes.Left.Grid.Style = Steema.TeeChart.Drawing.DashStyle.Solid;
			this.Chart.Axes.Left.Grid.Color = UIColor.White.CGColor;
			this.Chart.Axes.Left.Grid.Width = 2;
			this.Chart.Axes.Left.Labels.Font.Color = textColor;
			this.Chart.Axes.Left.MaximumOffset = 30;
			
			// Bottom axis
			this.Chart.Axes.Bottom.AxisPen.Visible = false;
			this.Chart.Axes.Bottom.Grid.Visible = false;
			this.Chart.Axes.Bottom.Ticks.Visible = false;
			this.Chart.Axes.Bottom.MinorTicks.Visible = false;
			this.Chart.Axes.Bottom.MinorGrid.Visible = false;
			this.Chart.Axes.Bottom.Grid.Visible = false;
			this.Chart.Axes.Bottom.Labels.Angle = 90;
			this.Chart.Axes.Bottom.Labels.Font.Color = textColor;
			
			// Consumption series
			Steema.TeeChart.Styles.Bar testSeries = new Steema.TeeChart.Styles.Bar() { VertAxis = Steema.TeeChart.Styles.VerticalAxis.Left };
			testSeries.Marks.Visible = false;
			testSeries.Color = UIColor.Blue.CGColor;
			testSeries.XValues.DateTime = true;
			testSeries.BarWidthPercent = 100 * (int) (float)UIKit.UIScreen.MainScreen.Scale;
			testSeries.SideMargins = true;
			this.Chart.Series.Add(testSeries);
		}

		void Chart_GetAxisLabel(object sender, GetAxisLabelEventArgs e)
		{
			if (sender == this.Chart.Axes.Left)
				e.LabelText = e.LabelText;
		}

		private void UpdateChart()
		{
			double[] values = { 20, 9, 35, 18, 7, 12, 15, 22, 9, 28 };
			DateTime[] dates = new DateTime[values.Length];
			for (int i = 0; i < values.Length; i++)
				dates[i] = DateTime.Now.AddDays(i);

			// Consumption
			Steema.TeeChart.Styles.Bar testSeries = this.Chart.Series[0] as Steema.TeeChart.Styles.Bar;
			testSeries.Clear();

			// Process usage data
			{
				int i = 0;
				while (i < values.Length)
				{
					testSeries.Add(dates[i], values[i], testSeries.Color);
					i++;
				}
			}
			
			this.Chart.Axes.Bottom.Increment = Steema.TeeChart.Utils.GetDateTimeStep(Steema.TeeChart.DateTimeSteps.OneDay);
			this.Chart.Axes.Bottom.Labels.DateTimeFormat = "MM/dd";
		}
    }
}